@@ -4,20 +4,23 @@ library(testthat)
 context("extremes")
 
 test_that("param info", {
-  ans1 <- structure(list(1L, NA_real_, 1e-06, 1L, NA_real_, 1e-06, 2L,
-                         NA_real_, NA_real_, 3L, 0.999999, 1e-06, 3L, 0.999999, 1e-06),
+  ans1 <- structure(list("slope", NA_real_, 1e-06,
+                         "slope", NA_real_, 1e-06,
+                         "intercept", NA_real_, NA_real_,
+                         "bound", NA_real_, NA_real_,
+                         "bound", NA_real_, NA_real_),
                     .Dim = c(3L,  5L), .Dimnames = list(c("type", "upper", "lower"), NULL))
   expect_identical(rpf.paramInfo(rpf.drm(factors=2)), ans1)
   
-  ans2 <- structure(list(1L, NA_real_, 1e-06, 1L, NA_real_, 1e-06, 2L,
-                         NA_real_, NA_real_, 2L, NA_real_, NA_real_),
+  ans2 <- structure(list("slope", NA_real_, 1e-06, "slope", NA_real_, 1e-06,
+                         "intercept", NA_real_, NA_real_, "intercept", NA_real_, NA_real_),
                     .Dim = 3:4, .Dimnames = list(     c("type", "upper", "lower"), NULL))
   expect_identical(rpf.paramInfo(rpf.grm(outcomes=3, factors=2)), ans2)
   
-  ans3 <- structure(list(1L, NA_real_, 1e-06, 1L, NA_real_, 1e-06, 1L,
-                         NA_real_, NA_real_, 1L, NA_real_, NA_real_, 1L, NA_real_,
-                         NA_real_, 2L, NA_real_, NA_real_, 2L, NA_real_, NA_real_,
-                         2L, NA_real_, NA_real_),
+  ans3 <- structure(list("slope", NA_real_, 1e-06, "slope", NA_real_, 1e-06, "slope",
+                         NA_real_, NA_real_, "slope", NA_real_, NA_real_, "slope", NA_real_,
+                         NA_real_, "intercept", NA_real_, NA_real_, "intercept", NA_real_, NA_real_,
+                         "intercept", NA_real_, NA_real_),
                     .Dim = c(3L, 8L), .Dimnames = list(     c("type", "upper", "lower"), NULL))
   expect_identical(rpf.paramInfo(rpf.nrm(outcomes=4, factors=2)), ans3)
 })
@@ -27,10 +30,10 @@ param <- list()
 # repair the poor version of drm TODO
 #spec [[length(spec) +1]] <- rpf.drm(poor=TRUE)
 #param[[length(param)+1]] <- c(1, 0, 0)
-spec [[length(spec) +1]] <- rpf.drm(multidimensional=TRUE)
-param[[length(param)+1]] <- c(1, 0, .05, .95)
+spec [[length(spec) +1]] <- rpf.drm()
+param[[length(param)+1]] <- c(1, 0, logit(.05), logit(.95))
 
-spec [[length(spec) +1]] <- rpf.grm(3, multidimensional=TRUE)
+spec [[length(spec) +1]] <- rpf.grm(3)
 param[[length(param)+1]] <- c(1, 1, -1)
 
 spec [[length(spec) +1]] <- rpf.nrm(3)
