@@ -21,9 +21,10 @@ checkDim <- function(item, param) {
 test_that("3PL ICC", {
   i1 <- rpf.drm()
   i1.p <- rpf.rparam(i1)
-  i1.p['u'] <- 1  # plink doesn't do upper bounds
+  i1.p['u'] <- logit(1)  # plink doesn't do upper bounds
   i2.p <- i1.p[1:3]
   i2.p[2] <-i2.p[2] / -i2.p[1]  # traditional parameterization
+  i2.p[3] <- 1/(1+exp(-i2.p[3]))
   checkDim(i1,i1.p)
   expect_equal(drm(t(i2.p), theta, 1)@prob[,2],
                rpf.prob(i1, i1.p, theta)[2,],
@@ -31,10 +32,12 @@ test_that("3PL ICC", {
 
   m1 <- rpf.drm(factors=2)
   m1.p <- rpf.rparam(m1)
-  m1.p['u'] <- 1  # plink doesn't do upper bounds
+  m1.p['u'] <- logit(1)  # plink doesn't do upper bounds
+  m2.p <- m1.p
+  m2.p['g'] <- 1/(1+exp(-m2.p['g']))
   checkDim(m1,m1.p)
   expect_equivalent(rpf.prob(m1, m1.p, theta.2d)[2,],
-                    drm(t(m1.p[1:4]), t(theta.2d), dimensions=2)@prob[,3],
+                    drm(t(m2.p[1:4]), t(theta.2d), dimensions=2)@prob[,3],
                     info="M3PL")
 })
 
